@@ -1483,5 +1483,88 @@ public abstract class Page implements Serializable {
 		}
 		cookie = new ArrayList<Cookie>();
 	}
+
+	/**
+	 * レイアウトパーツページ。
+	 */
+	public class LayoutParts {
+		Tag	div;
+		Page	page;
+		Page	base;
+		/**
+		 * コンストラクタ。
+		 * @param p 埋め込むページ。
+		 * @param tag 埋め込み先のタグ。
+		 */
+		public LayoutParts( Page p, Tag tag ) throws Page.PageException {
+			page = p;
+			div = tag;
+			if ( page == null || div == null ) {
+				throw new Page.PageException( "doLayout: null を渡しています。" );
+			}
+			base = div.getAssignedPage();
+		}
+		void checkSame( Page layout ) throws Page.PageException {
+			if ( base != layout ) {
+				throw new Page.PageException( "doLayout: レイアウト適用先のページインスタンスが統一されていません" );
+			}
+		}
+		void set() {
+			if ( div instanceof PageBypassedDiv ) {
+				PageBypassedDiv	pbd = (PageBypassedDiv)div;
+				pbd.setBypassPage( base.getPageServerInformation().getHistorySet().get( base.getHistoryKey() ), page );
+			}
+			else {
+				div.include( page, true );
+			}
+		}
+	}
+
+	/**
+	 * レイアウトの適用。<br>
+	 * this とはレイアウトを示す別ページインスタンスに this と parts の示す内容を
+	 * 設定し、this の出力内容をそのレイアウトに変更します。<br>
+	 * また、ページタイトルがあれば引き継ぎます。
+	 * 
+	 * @param include_me this の埋め込み先。
+	 * @param parts this 以外の埋め込みページ。
+	 */
+	public void doLayout( Tag include_me, LayoutParts ... parts ) throws PageException {
+		if ( include_me == null ) {
+			throw new PageException( "doLayout: include_me が null です" );
+		}
+		Page	base = include_me.getAssignedPage();
+		if ( base == null ) {
+			throw new PageException( "doLayout: include_me がどのページにも所属していません" );
+		}
+		if ( base == this ) {
+			throw new PageException( "doLayout: レイアウト適用先のページインスタンスが this です" );
+		}
+		if ( include_me instanceof PageBypassedDiv ) {
+			throw new PageException( "doLayout: this の設定先が PageBypassedDiv です" );
+		}
+		for ( int i = 0; i < parts.length; i++ ) {
+			parts[i].checkSame( base );
+		}
+
+		Tag	title = getFirstTagByType( "title" );
+		if ( title != null ) {
+			Tag	lo_title = base.getFirstTagByType( "title" );
+			if ( lo_title == null ) {
+				Tag	head = base.getFirstTagByType( "head" );
+				if ( head != null ) {
+					head.addHTMLPart( title.getReplica() );
+				}
+			}
+			else {
+				lo_title.setValueString( title.getValueString() );
+			}
+		}
+		include_me.include( this, true );
+		moveMainTag( base );
+		for ( int i = 0; i < parts.length; i++ ) {
+			parts[i].set();
+		}
+	}
 }
 
