@@ -376,7 +376,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 		 * @return true:一致、false:不一致。
 		 */
 		private boolean equalsString( String o ) {
-			return prot.equals( o );
+			return prot.equalsIgnoreCase( o );
 		}
 		/**
 		 * URIのスキーマを返します。
