@@ -6,19 +6,20 @@
  */
 package paraselene.supervisor;
 
-import java.io.*;
+import java.util.*;
 
 /**
  * サーバー情報。
  */
-public class PageServerInformation implements ServerInformation, Serializable {
+public class PageServerInformation implements ServerInformation {
+	private static HashMap<String, PageFactory>	fact = new HashMap<String, PageFactory>();
+
 	private static final long serialVersionUID = 2L;
 	private String	server;
 	private String	context;
 	private TransactionSequencer	seq;
 	private boolean	search_flag;
 	private HistorySet	hist;
-	private PageFactory	fact;
 
 	PageServerInformation( DataHolder holder ) {
 		server = holder.getServerName();
@@ -26,7 +27,11 @@ public class PageServerInformation implements ServerInformation, Serializable {
 		seq = getTransactionSequencer();
 		search_flag = holder.isSearchEngine();
 		hist = holder.getHistorySet();
-		fact = holder.getPageFactory();
+		synchronized( fact ) {
+			if ( fact.get( context ) == null ) {
+				fact.put( context, holder.getPageFactory() );
+			}
+		}
 	}
 
 	public String getServerName() { return server; }
@@ -34,6 +39,6 @@ public class PageServerInformation implements ServerInformation, Serializable {
 	public TransactionSequencer getTransactionSequencer() { return seq; }
 	public boolean isSearchEngine() { return search_flag; }
 	public HistorySet getHistorySet() { return hist; }
-	public PageFactory getPageFactory() { return fact; }
+	public PageFactory getPageFactory() { return fact.get( context ); }
 }
 
