@@ -433,6 +433,7 @@ public abstract class Supervisor extends HttpServlet {
 						return;
 					}
 					if ( holder.session_null && path_data != null ) {
+						Option.trace( "%s(%s->%s)", IllegalRequest.SESSION_ERROR, path_data.from.getID(), path_data.to.getID() );
 						fw = onIllegalRequest( IllegalRequest.SESSION_ERROR, req, path_data.from, path_data.to );
 						if ( fw != null ) {
 							session_f = fw.session_clear_f;
@@ -517,6 +518,7 @@ public abstract class Supervisor extends HttpServlet {
 						last_page = sub;
 					}
 					else {
+						Option.trace( "%s(%s->%s)", IllegalRequest.NOT_FOUND_HISTORY, last_page.getID(), next_page.getID() );
 						fw = onIllegalRequest( IllegalRequest.NOT_FOUND_HISTORY, req, last_page, next_page );
 						if ( fw != null ) {
 							session_f = fw.session_clear_f;
@@ -551,6 +553,7 @@ public abstract class Supervisor extends HttpServlet {
 			}
 
 			if ( path_data.called ) {
+				Option.trace( "%s(%s->%s)", IllegalRequest.REPEAT_SAME_REQUEST, last_page.getID(), next_page.getID() );
 				fw = onIllegalRequest( IllegalRequest.REPEAT_SAME_REQUEST, req, last_page, next_page );
 				if ( fw != null ) {
 					session_f = fw.session_clear_f;
@@ -579,7 +582,7 @@ public abstract class Supervisor extends HttpServlet {
 					do_page = last_page.reflect( req );
 				}
 				if ( do_page == null && !(last_page instanceof NullPage) && req.getItemCount() > 0 ) {
-					Option.trace( "reflect -> IllegalRequest.DISAPPROVAL_REQUEST" );
+					Option.trace( "%s(%s->%s)", IllegalRequest.DISAPPROVAL_REQUEST, last_page.getID(), next_page.getID() );
 					fw = onIllegalRequest( IllegalRequest.DISAPPROVAL_REQUEST, req, last_page, next_page );
 					if ( fw != null ) {
 						session_f = fw.session_clear_f;
@@ -679,6 +682,11 @@ public abstract class Supervisor extends HttpServlet {
 			}
 			Page[]	out_ret = oh.getPage();
 			if ( out_ret == null ) {
+				if ( fw.isLeave() ) {
+					fw.Action( this, res );
+					if ( session_f )	clear_session( session );
+					return;
+				}
 				System.out.println( "output_call false" );
 				fw = new Forward( 500 );
 				fw.Action( this, res );
@@ -769,7 +777,7 @@ public abstract class Supervisor extends HttpServlet {
 			session = holder.getRequest().getSession( true );
 			session.setAttribute( SESSION_DATA, data );
 		}
-		if ( isPRG() && !session_f && param.getMethod() == RequestParameter.Method.POST ) {
+		if ( isPRG() && !(out_ret[1] instanceof Downloadable) && !session_f && param.getMethod() == RequestParameter.Method.POST ) {
 			data.redirect( out_ret, fw, param ).Action( this, res );
 		}
 		else {
