@@ -53,7 +53,7 @@ public class TransactionSequencer implements Serializable {
 	public static final String[] LINK_DEF = new String[] {
 		"PARASELENE(PAGE)", "PARASELENE(HTTP)", "PARASELENE(HTTPS)"
 	};
-	private volatile int seq = 0;
+	private volatile int seq_no = 0;
 	private HashMap<Integer,Boolean>	no_map = new HashMap<Integer,Boolean>();
 	private static final String[] HEAD = { "seleno", "lilith" };
 	private static final int HEAD_LENGTH = 6;
@@ -65,8 +65,8 @@ public class TransactionSequencer implements Serializable {
 		long	dt = (new Date().getTime() / 1000) & 0x7fffff;
 		int		ret = (int)(dt << 8);
 		synchronized( this ) {
-			ret |= (seq & 0xff);
-			seq += (int)(Math.random() * 5);
+			ret |= (seq_no & 0xff);
+			seq_no += (int)(Math.random() * 5);
 			no_map.put( ret, false );
 		}
 		return ret;
