@@ -61,10 +61,31 @@ public class MimeMake {
 		}
 	}
 
-	public static void main( String[] argv ) throws Exception {
+	private static String[] marge( String[] a, String[] b ) {
+		HashMap<String, String>	tmp = new HashMap<String, String>();
+		if ( a != null ) {
+			for ( int i = 0; i < a.length; i++ ) {
+				tmp.put( a[i], a[i] );
+			}
+		}
+		if ( b != null ) {
+			for ( int i = 0; i < b.length; i++ ) {
+				tmp.put( b[i], b[i] );
+			}
+		}
+		String[]	ret = new String[tmp.size()];
+		int	n = 0;
+		for ( String k: tmp.keySet() ) {
+			ret[n] = k;
+			n++;
+		}
+		return ret;
+	}
+
+	private static void read( File file, TreeMap<String, String[]> map ) throws Exception {
 		BufferedReader	br = new BufferedReader(
 			new InputStreamReader(
-				new FileInputStream( "../template/mime.types" )
+				new FileInputStream( file )
 			)
 		);
 		while( true ) {
@@ -76,18 +97,33 @@ public class MimeMake {
 			String[]	l = line.split( "\\p{Space}" );
 			if ( l.length < 2 )	continue;
 			ArrayList<String>	data = new ArrayList<String>();
-			data.add( l[0] );
 			for ( int i = 1; i < l.length; i++ ) {
 				if ( l[i].isEmpty() )	continue;
 				data.add( l[i] );
 			}
-			if ( data.size() > 1 ) {
-				table.add( data.toArray( new String[0] ) );
+			if ( data.size() > 0 ) {
+				map.put( l[0], marge( map.get( l[0] ), data.toArray( new String[0] ) ) );
 			}
 		}
 		br.close();
+	}
 
-		br = new BufferedReader(
+	public static void main( String[] argv ) throws Exception {
+		TreeMap<String, String[]>	map = new TreeMap<String, String[]>();
+		for ( int i = 0; i < argv.length; i++ ) {
+			read( new File( argv[i] ), map );
+		}
+		for ( String k: map.keySet() ) {
+			String[]	v = map.get( k );
+			String[]	data = new String[v.length + 1];
+			data[0] = k;
+			for ( int i = 0; i < v.length; i++ ) {
+				data[i + 1] = v[i];
+			}
+			table.add( data );
+		}
+
+		BufferedReader	br = new BufferedReader(
 			new InputStreamReader(
 				new FileInputStream( "../template/MimeType.java" )
 			)
